.. currentmodule:: kombu.transport.virtual.exchange

.. automodule:: kombu.transport.virtual.exchange

    .. contents::
        :local:

    Direct
    ------

    .. autoclass:: DirectExchange
        :members:
        :undoc-members:

    Topic
    -----

    .. autoclass:: TopicExchange
        :members:
        :undoc-members:

    Fanout
    ------

    .. autoclass:: FanoutExchange
        :members:
        :undoc-members:

    Interface
    ---------

    .. autoclass:: ExchangeType
        :members:
        :undoc-members:

